From dtor_core@ameritech.net Fri Apr 29 07:06:44 2005
From: Dmitry Torokhov <dtor_core@ameritech.net>
Subject: sysfs: (driver/pci) if show/store is missing return -EIO
Date: Fri, 29 Apr 2005 01:26:27 -0500

sysfs: fix drivers/pci so if an attribute does not implement
       show or store method read/write will return -EIO
       instead of 0.

Signed-off-by: Dmitry Torokhov <dtor@mail.ru>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>


---
 drivers/pci/hotplug/pci_hotplug_core.c |    4 ++--
 drivers/pci/hotplug/rpadlpar_sysfs.c   |    2 +-
 drivers/pci/pci-driver.c               |   26 ++++++++++++++------------
 3 files changed, 17 insertions(+), 15 deletions(-)

--- gregkh-2.6.orig/drivers/pci/hotplug/rpadlpar_sysfs.c	2005-05-04 23:53:48.000000000 -0700
+++ gregkh-2.6/drivers/pci/hotplug/rpadlpar_sysfs.c	2005-05-04 23:53:51.000000000 -0700
@@ -48,7 +48,7 @@
 	struct dlpar_io_attr *dlpar_attr = container_of(attr,
 						struct dlpar_io_attr, attr);
 	return dlpar_attr->store ?
-		dlpar_attr->store(dlpar_attr, buf, nbytes) : 0;
+		dlpar_attr->store(dlpar_attr, buf, nbytes) : -EIO;
 }
 
 static struct sysfs_ops dlpar_attr_sysfs_ops = {
--- gregkh-2.6.orig/drivers/pci/pci-driver.c	2005-05-04 23:53:48.000000000 -0700
+++ gregkh-2.6/drivers/pci/pci-driver.c	2005-05-04 23:53:51.000000000 -0700
@@ -335,13 +335,14 @@
 {
 	struct device_driver *driver = kobj_to_pci_driver(kobj);
 	struct driver_attribute *dattr = attr_to_driver_attribute(attr);
-	ssize_t ret = 0;
+	ssize_t ret;
 
-	if (get_driver(driver)) {
-		if (dattr->show)
-			ret = dattr->show(driver, buf);
-		put_driver(driver);
-	}
+	if (!get_driver(driver))
+		return -ENODEV;
+
+	ret = dattr->show ? dattr->show(driver, buf) : -EIO;
+
+	put_driver(driver);
 	return ret;
 }
 
@@ -351,13 +352,14 @@
 {
 	struct device_driver *driver = kobj_to_pci_driver(kobj);
 	struct driver_attribute *dattr = attr_to_driver_attribute(attr);
-	ssize_t ret = 0;
+	ssize_t ret;
 
-	if (get_driver(driver)) {
-		if (dattr->store)
-			ret = dattr->store(driver, buf, count);
-		put_driver(driver);
-	}
+	if (!get_driver(driver))
+		return -ENODEV;
+
+	ret = dattr->store ? dattr->store(driver, buf, count) : -EIO;
+
+	put_driver(driver);
 	return ret;
 }
 
--- gregkh-2.6.orig/drivers/pci/hotplug/pci_hotplug_core.c	2005-05-04 23:53:48.000000000 -0700
+++ gregkh-2.6/drivers/pci/hotplug/pci_hotplug_core.c	2005-05-04 23:53:51.000000000 -0700
@@ -73,7 +73,7 @@
 {
 	struct hotplug_slot *slot = to_hotplug_slot(kobj);
 	struct hotplug_slot_attribute *attribute = to_hotplug_attr(attr);
-	return attribute->show ? attribute->show(slot, buf) : 0;
+	return attribute->show ? attribute->show(slot, buf) : -EIO;
 }
 
 static ssize_t hotplug_slot_attr_store(struct kobject *kobj,
@@ -81,7 +81,7 @@
 {
 	struct hotplug_slot *slot = to_hotplug_slot(kobj);
 	struct hotplug_slot_attribute *attribute = to_hotplug_attr(attr);
-	return attribute->store ? attribute->store(slot, buf, len) : 0;
+	return attribute->store ? attribute->store(slot, buf, len) : -EIO;
 }
 
 static struct sysfs_ops hotplug_slot_sysfs_ops = {
